==> open-xchange-documents-backend_7.10.2.orig.tar.bz2: open-xchange-documents-backend-7.10.2/com.openexchange.office.filter.ooxml.docx/src/com/openexchange/office/filter/ooxml/docx/components/AlternateContentComponent.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.filter.ooxml.docx.components;

import java.util.ArrayList;
import java.util.List;
import org.docx4j.mce.AlternateContent;
import org.docx4j.mce.AlternateContent.Choice;
import org.docx4j.mce.AlternateContent.Fallback;
import org.docx4j.wml.Drawing;
import com.openexchange.office.filter.core.IContentAccessor;
import com.openexchange.office.filter.core.DLNode;
import com.openexchange.office.filter.core.component.ComponentContext;
import com.openexchange.office.filter.ooxml.OperationDocument;
import com.openexchange.office.filter.ooxml.components.Component;
import com.openexchange.office.filter.ooxml.components.MultiComponent;
import com.openexchange.office.filter.ooxml.components.VMLBase;
import com.openexchange.office.filter.ooxml.components.VMLRootComponent;
import com.openexchange.office.filter.ooxml.docx.tools.DrawingML;

public class AlternateContentComponent extends ShapeComponent_Root {

	public AlternateContentComponent(ComponentContext<OperationDocument, Component> parentContext, DLNode<Object> _node, int _componentNumber) {
        super(parentContext, _node, _componentNumber);

        final List<Component> shapes = new ArrayList<Component>(2);
		final AlternateContent alternateContent = (AlternateContent)getObject();
		final List<Choice> choices = alternateContent.getChoice();
		for (int i=0; i<choices.size(); i++) {
			final Choice choice = choices.get(i);
			final String requires = choice.getRequires();
			if(requires.equals("wps")||requires.equals("wpg")) {
				final List<Object> any = choice.getAny();
				final Object o = any.get(0);
				if(o instanceof Drawing) {
					shapes.add(new ShapeComponent(getOperationDocument(), new DrawingML.DrawingML_root(getOperationDocument(), (Drawing)o), getComponentNumber()));
				}
			}
			else if (requires.equals("wpc")) {
			    final List<Object> any = choice.getAny();
			    final Object o = any.get(0);
			    if(o instanceof Drawing) {
			        shapes.add(new ShapeComponent(getOperationDocument(), new DrawingML.DrawingML_root(getOperationDocument(), (Drawing)o), getComponentNumber()));
			    }
			}
			else {
				// we don't support changes of this type, so we remove it...
				// changes will be applied to the fallback
				choices.remove(i--);
			}
		}
		final Fallback fallback = alternateContent.getFallback();
		if(fallback!=null) {
			final List<Object> any = fallback.getAny();
			if(any.size()==1) {
				final Object o = any.get(0);
				if(o instanceof IContentAccessor) {
				    final VMLBase vmlBase = (VMLBase) new VMLRootComponent("text", operationDocument, (IContentAccessor)o).getNextChildComponent(null, null);
				    if(vmlBase!=null) {
				        shapes.add(new ShapeComponent(getOperationDocument(), vmlBase, getComponentNumber()));
				    }
				}
			}
		}
		if(!shapes.isEmpty()) {
		    shapeType = ((ShapeComponent)shapes.get(0)).getType();
            shapeComponent = MultiComponent.createComponent(parentContext.getOperationDocument(), shapes);
		}
    }
}

==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.filter.ooxml.docx/src/com/openexchange/office/filter/ooxml/docx/components/AlternateContentComponent.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.filter.ooxml.docx.components;

import java.util.ArrayList;
import java.util.List;
import org.docx4j.mce.AlternateContent;
import org.docx4j.mce.AlternateContent.Choice;
import org.docx4j.mce.AlternateContent.Fallback;
import org.docx4j.wml.Drawing;
import com.openexchange.office.filter.core.IContentAccessor;
import com.openexchange.office.filter.core.DLNode;
import com.openexchange.office.filter.core.component.ComponentContext;
import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
import com.openexchange.office.filter.ooxml.components.MultiComponent;
import com.openexchange.office.filter.ooxml.components.VMLBase;
import com.openexchange.office.filter.ooxml.components.VMLRootComponent;
import com.openexchange.office.filter.ooxml.docx.tools.DrawingML;

public class AlternateContentComponent extends ShapeComponent_Root {

	public AlternateContentComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> _node, int _componentNumber) {
        super(parentContext, _node, _componentNumber);

        final List<OfficeOpenXMLComponent> shapes = new ArrayList<OfficeOpenXMLComponent>(2);
		final AlternateContent alternateContent = (AlternateContent)getObject();
		final List<Choice> choices = alternateContent.getChoice();
		for (int i=0; i<choices.size(); i++) {
			final Choice choice = choices.get(i);
			final String requires = choice.getRequires();
			if(requires.equals("wps")||requires.equals("wpg")) {
				final List<Object> any = choice.getAny();
				final Object o = any.get(0);
				if(o instanceof Drawing) {
					shapes.add(new ShapeComponent(getOperationDocument(), new DrawingML.DrawingML_root(getOperationDocument(), (Drawing)o), getComponentNumber()));
				}
			}
			else if (requires.equals("wpc")) {
			    final List<Object> any = choice.getAny();
			    final Object o = any.get(0);
			    if(o instanceof Drawing) {
			        shapes.add(new ShapeComponent(getOperationDocument(), new DrawingML.DrawingML_root(getOperationDocument(), (Drawing)o), getComponentNumber()));
			    }
			}
			else {
				// we don't support changes of this type, so we remove it...
				// changes will be applied to the fallback
				choices.remove(i--);
			}
		}
		final Fallback fallback = alternateContent.getFallback();
		if(fallback!=null) {
			final List<Object> any = fallback.getAny();
			if(any.size()==1) {
				final Object o = any.get(0);
				if(o instanceof IContentAccessor) {
				    final VMLBase vmlBase = (VMLBase) new VMLRootComponent("text", operationDocument, (IContentAccessor)o).getNextChildComponent(null, null);
				    if(vmlBase!=null) {
				        shapes.add(new ShapeComponent(getOperationDocument(), vmlBase, getComponentNumber()));
				    }
				}
			}
		}
		if(!shapes.isEmpty()) {
		    shapeType = ((ShapeComponent)shapes.get(0)).getType();
            shapeComponent = MultiComponent.createComponent(parentContext.getOperationDocument(), shapes);
		}
    }
}
